==> idoit-api-2.0.1.zip: src/classes/modules/api/src/Endpoint/v2/Cmdb/Category/Archive.php <==
<?php

namespace idoit\Module\Api\Endpoint\v2\Cmdb\Category;

use idoit\Api\EndpointDefinition;
use idoit\Api\JsonRpcResponse;
use idoit\Api\Parameter\Parameter;
use idoit\Api\Parameter\RequiredParameter;
use idoit\Module\Api\Category\Entry;
use idoit\Module\Api\Endpoint\v2\Cmdb\AbstractCmdbEndpoint;
use idoit\Module\Api\Exception\JsonRpc\AuthenticationException;
use idoit\Module\Api\Exception\JsonRpc\InternalErrorException;
use isys_auth;
use isys_module_cmdb;
use Symfony\Component\HttpFoundation\Request;

/**
 * CMDB category archive endpoint (v2).
 *
 * @see       API-484
 * @package   idoit\Api
 * @copyright synetics GmbH
 * @license   http://www.i-doit.com/license
 */
class Archive extends AbstractCmdbEndpoint
{
    public function getDefinition(): EndpointDefinition
    {
        return new EndpointDefinition('cmdb.category.archive.v2', 'Will archive a singular category entry from i-doit', [
            new RequiredParameter('object', Parameter::TYPE_INTEGER, 'Numeric object ID', fn ($id) => $id > 0),
            new RequiredParameter('category', Parameter::TYPE_STRING, 'Category string constant', fn ($category) => strpos($category, 'C__CAT') === 0 && defined($category)),
            new RequiredParameter('entry', Parameter::TYPE_INTEGER, 'Numeric entry ID', fn ($entry) => $entry > 0),
        ]);
    }

    public function request(Request $request): JsonRpcResponse
    {
        $objectId = $request->request->get('object');
        $categoryConstant = $request->request->get('category');
        $entryId = $request->request->get('entry');

        // Create category entry instance
        $categoryEntry = new Entry($objectId, $categoryConstant, $entryId);

        // Check rights
        $isAllowedToArchive = isys_module_cmdb::getAuth()->has_rights_in_obj_and_category(isys_auth::ARCHIVE, $objectId, $categoryConstant);

        if (!$isAllowedToArchive) {
            throw new AuthenticationException('You are not allowed to archive this category entry.');
        }

        // @see API-191 Check and react to the object lock.
        $this->lockObject($objectId);

        if (!$categoryEntry->archive()) {
            throw new InternalErrorException('Unable to archive category entry.');
        }

        // @see API-191 Unlock the object once the request has finished.
        $this->unlockObject($objectId);

        return new JsonRpcResponse([
            'success' => true,
            'message' => "Entry {$entryId} has been successfully archived."
        ]);
    }
}

==> idoit-api-2.2.zip: src/classes/modules/api/src/Endpoint/v2/Cmdb/Category/Archive.php <==
<?php

namespace idoit\Module\Api\Endpoint\v2\Cmdb\Category;

use idoit\Api\EndpointDefinition;
use idoit\Api\JsonRpcResponse;
use idoit\Api\Parameter\Parameter;
use idoit\Api\Parameter\RequiredParameter;
use idoit\Module\Api\Category\Entry;
use idoit\Module\Api\Endpoint\v2\Cmdb\AbstractCmdbEndpoint;
use idoit\Module\Api\Exception\JsonRpc\AuthenticationException;
use idoit\Module\Api\Exception\JsonRpc\InternalErrorException;
use isys_auth;
use isys_module_cmdb;
use Symfony\Component\HttpFoundation\Request;

/**
 * CMDB category archive endpoint (v2).
 *
 * @see       API-484
 * @package   idoit\Api
 * @copyright synetics GmbH
 * @license   http://www.i-doit.com/license
 */
class Archive extends AbstractCmdbEndpoint
{
    public function getDefinition(): EndpointDefinition
    {
        return new EndpointDefinition('cmdb.category.archive.v2', 'LC__ADDON__API__ENDPOINT__CMDB_CATEGORY_ARCHIVE', [
            new RequiredParameter('object', Parameter::TYPE_INTEGER, 'LC__ADDON__API__PARAMETER__OBJECT_ID', fn ($id) => $id > 0),
            new RequiredParameter('category', Parameter::TYPE_STRING, 'LC__ADDON__API__PARAMETER__CATEGORY_CONSTANT', fn ($category) => strpos($category, 'C__CAT') === 0 && defined($category)),
            new RequiredParameter('entry', Parameter::TYPE_INTEGER, 'LC__ADDON__API__PARAMETER__ID', fn ($entry) => $entry > 0),
        ]);
    }

    public function request(Request $request): JsonRpcResponse
    {
        $objectId = $request->request->get('object');
        $categoryConstant = $request->request->get('category');
        $entryId = $request->request->get('entry');

        // Create category entry instance
        $categoryEntry = new Entry($objectId, $categoryConstant, $entryId);

        // Check rights
        $isAllowedToArchive = isys_module_cmdb::getAuth()->has_rights_in_obj_and_category(isys_auth::ARCHIVE, $objectId, $categoryConstant);

        if (!$isAllowedToArchive) {
            throw new AuthenticationException('You are not allowed to archive this category entry.');
        }

        // @see API-191 Check and react to the object lock.
        $this->lockObject($objectId);

        if (!$categoryEntry->archive()) {
            throw new InternalErrorException('Unable to archive category entry.');
        }

        // @see API-191 Unlock the object once the request has finished.
        $this->unlockObject($objectId);

        return new JsonRpcResponse([
            'success' => true,
            'message' => "Entry {$entryId} has been successfully archived."
        ]);
    }
}
